@@ -15,6 +15,12 @@ class Tool(object):
         return json_util(data)
 
 
+tool = Tool()
+a = tool.json_change(1)
+print(type(a))
+
+
+
 
 
 
